Exception: Capybara::Apparition::TimeoutError
- Defined in:
- lib/capybara/apparition/errors.rb
Instance Method Summary collapse
-
#initialize(message = nil) ⇒ TimeoutError
constructor
A new instance of TimeoutError.
- #message ⇒ Object
Constructor Details
#initialize(message = nil) ⇒ TimeoutError
Returns a new instance of TimeoutError.
201 202 203 |
# File 'lib/capybara/apparition/errors.rb', line 201 def initialize( = nil) = end |
Instance Method Details
#message ⇒ Object
205 206 207 208 209 210 211 |
# File 'lib/capybara/apparition/errors.rb', line 205 def "Timed out waiting for response to #{@message}. It's possible that this happened " \ 'because something took a very long time (for example a page load was slow). ' \ 'If so, setting the Apparition :timeout option to a higher value will help ' \ '(see the docs for details). If increasing the timeout does not help, this is ' \ 'probably a bug in Apparition - please report it to the issue tracker.' end |